local ui = {}
local vars = dofile'vars.lua'

local options_box = iup.vbox{} --contains toggle controls
local options = {
	{
		key='IsAutoUnload',
		ctrl=iup.stationtoggle{title='Auto-Unload'},
		help='This enables auto-unloading of the manufactured item when a manufacturing mission completes',
	},{
		key='IsOneWarning',
		ctrl=iup.stationtoggle{title='One Warning per Mission'},
		help='If enabled the warning message will not be shown more than once per manufacturing mission (it can still be shown manually using /mfg)',
	},
}

local help_text = 'MfgAide v'..MfgAide.version..'\n'..
[[MfgAide compares the items needed to be delivered for an active manufacturing mission to what you have in inventory and lists the items you are missing. It will not search the cargo of your other ships present, nor will it purchase the needed items.

To display the missing items manually, use the command: ]]..'\127a0a0a0/mfg\127o'..[[

For setting additional options, use the command: ]]..'\127a0a0a0/mfg options\127o\n'

for _,opt in ipairs(options) do
	if opt.key and opt.help then help_text = help_text..'\n\127ffff00'..opt.ctrl.title..'\127o - '..opt.help end --append help string for each toggle control
	
	if opt.ctrl then iup.Append(options_box, opt.ctrl) end --create vbox with toggle controls
end

function ui:ShowHelp()
	StationHelpDialog:Open(help_text)
end

local button_help = iup.stationbutton{title="Help", hotkey=iup.K_h, action=ui.ShowHelp}
local button_ok = iup.stationbutton{title="OK"}

local frame = iup.vbox{
	iup.hbox{iup.fill{}, iup.label{title="MfgAide v"..MfgAide.version,font=Font.H3}, iup.fill{}},
	iup.fill{size=10},
	iup.hbox{iup.fill{size=12}, options_box, iup.fill{}, gap=8},
	iup.fill{size=8},
	iup.hbox{button_help, iup.fill{}, button_ok, gap=8},
	alignment="ACENTER",
}

-- Create Dialog --

ui.dialog = iup.dialog{
	iup.vbox{
		iup.fill{},
		iup.hbox{
			iup.fill{},
			iup.stationhighopacityframe{
				iup.stationhighopacityframebg{
					frame,
					expand="NO",
					gap=8,
				},
			},
			iup.fill{},
		},
		iup.fill{},
	},
	BGCOLOR = "0 0 0 160 *",
	FULLSCREEN="YES",
	RESIZE="NO",
	BORDER="NO",
	MENUBOX="YES",
	TOPMOST="YES",
	DEFAULTESC=button_ok,
	DEFAULTENTER=button_ok,
}
ui.dialog:map()

function ui:Show()
	ui.Update(self) --reset control values in case of changed by console

	ShowDialog(ui.dialog,iup.CENTER,iup.CENTER)
	iup.Refresh(ui.dialog)
end

--capture state of controls and save to config
function ui:Hide()
	for _,opt in ipairs(options) do
		if opt.ctrl and opt.key then
			local value = opt.ctrl.value=="ON"
			vars.SaveVars(opt.key, value)
		end
	end
	
	HideDialog(ui.dialog)
end

--Set all control values to config values
function ui:Update()
	for _,opt in ipairs(options) do
		if opt.ctrl and opt.key then opt.ctrl.value = vars.GetVars(opt.key) and "ON" or "OFF" end
	end
end

function button_ok.action() ui.Hide(button_ok) end

return ui, vars